﻿using UnityEngine;

public class CameraBackgroundColor : MVRScript
{
    private Camera mainCam;
    private Camera screenshotCam;
    private Camera thumbnailCam;
    private Camera windowCam;
    private JSONStorableColor jColor;

    public override void Init()
    {
        mainCam = CameraTarget.centerTarget.targetCamera;
        screenshotCam = SuperController.singleton.hiResScreenshotCamera;
        thumbnailCam = SuperController.singleton.screenshotCamera;
        Atom windowCamAtom = GetSceneAtoms().Find((Atom a) => { return a.type == "WindowCamera"; });
        if (windowCamAtom != null)
        {
            CameraControl cameraControl = windowCamAtom.GetStorableByID("CameraControl") as CameraControl;
            if (cameraControl != null)
                windowCam = cameraControl.cameraToControl;
        }

        jColor = new JSONStorableColor("Color", HSVColorPicker.RGBToHSV(0f, 0f, 1f), SetColor);
        RegisterColor(jColor);
        CreateColorPicker(jColor);
    }
    
    void Start() { SetColor(jColor.val.H, jColor.val.S, jColor.val.V); }

    void OnDestroy() { SetColor(0f, 0f, 0f); }

    private void OnEnable() { SetColor(jColor.val.H, jColor.val.S, jColor.val.V); }
    private void OnDisable() { SetColor(0f, 0f, 0f); }
    private void SetColor(float h, float s, float v)
    {
        mainCam.backgroundColor = Color.HSVToRGB(h, s, v);
        screenshotCam.backgroundColor = mainCam.backgroundColor;
        thumbnailCam.backgroundColor = mainCam.backgroundColor;
        windowCam.backgroundColor = mainCam.backgroundColor;
    }
}